@@ -62,7 +62,7 @@ class Scalar(torch.nn.Module):
         v:
             A 2D Tensor containing an initial guess of the wavespeed.
         grid_spacing:
-            The spatial grid cell size, specified with a single float
+            The spatial grid cell size, specified with a single real number
             (used for both dimensions) or a List or Tensor of length
             two (the length in each of the two dimensions).
         v_requires_grad:
@@ -115,7 +115,8 @@ class Scalar(torch.nn.Module):
                       model_gradient_sampling_interval)
 
 
-def scalar(v: Tensor, grid_spacing: Union[float, List[float], Tensor],
+def scalar(v: Tensor,
+           grid_spacing: Union[int, float, List[Union[int, float]], Tensor],
            dt: float,
            source_amplitudes: Optional[Tensor] = None,
            source_locations: Optional[Tensor] = None,
@@ -148,7 +149,7 @@ def scalar(v: Tensor, grid_spacing: Union[float, List[float], Tensor],
             not made of the model, so gradients will propagate back into
             the provided Tensor.
         grid_spacing:
-            The spatial grid cell size, specified with a single float
+            The spatial grid cell size, specified with a single real number
             (used for both dimensions) or a List or Tensor of length
             two (the length in each of the two dimensions).
         dt:
@@ -167,12 +168,17 @@ def scalar(v: Tensor, grid_spacing: Union[float, List[float], Tensor],
             index in the two spatial dimensions of the cell that each
             source is located in, relative to the origin of the model.
             Optional. Must be provided if `source_amplitudes` is. It should
-            have torch.long (int64) datatype.
+            have torch.long (int64) datatype. The location of each source
+            must be unique within the same shot (you cannot have two
+            sources in the same shot that both have location [1, 2], for
+            example).
         receiver_locations:
             A Tensor with dimensions [shot, receiver, 2], containing
             the coordinates of the cell containing each receiver. Optional.
             It should have torch.long (int64) datatype. If not provided,
-            the output `receiver_amplitudes` Tensor will be empty.
+            the output `receiver_amplitudes` Tensor will be empty. If
+            backpropagation will be performed, the location of each
+            receiver must be unique within the same shot.
         accuracy:
             An int specifying the finite difference order of accuracy. Possible
             values are 2, 4, 6, and 8, with larger numbers resulting in more
